.. currentmodule:: sardana.pool.poolpseudocounter

:mod:`~sardana.pool.poolpseudocounter`
=========================================

.. automodule:: sardana.pool.poolpseudocounter

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolPseudoCounter`


PoolPseudoCounter
-------------------

.. inheritance-diagram:: PoolPseudoCounter
    :parts: 1
    
.. autoclass:: PoolPseudoCounter
    :show-inheritance:
    :members:
    :undoc-members:

